@@ -31,8 +31,8 @@
 #    03/20/13           #1774      randerso      Added TimeConstraintsAdapter
 #    04/22/13           #1949      rjpeter       Added LockTableAdapter
 #    02/06/14           #2672      bsteffen      Added JTSEnvelopeAdapter
-
-#
+#    06/22/2015         #4573      randerso      Added JobProgressAdapter
+#    09/21/2015         #4486      rjpeter       Added FormattedDateAdapter
 #
 
 __all__ = [
@@ -43,6 +43,7 @@ __all__ = [
            'GregorianCalendarAdapter',
            'ActiveTableModeAdapter',
            'DateAdapter',
+           'FormattedDateAdapter',
            'LocalizationLevelSerializationAdapter',
            'LocalizationTypeSerializationAdapter',
            'GeometryTypeAdapter',
@@ -56,8 +57,8 @@ __all__ = [
            'ByteBufferAdapter',
            'TimeConstraintsAdapter',
            'LockTableAdapter',
-           'JTSEnvelopeAdapter'
-#           'GridDataHistoryAdapter',
+           'JTSEnvelopeAdapter',
+           'JobProgressAdapter',
            ]
 
 classAdapterRegistry = {}
@@ -80,5 +81,6 @@ def getAdapterRegistry():
             raise LookupError('Adapter class ' + x + ' has no ClassAdapter field ' + \
                               'and cannot be registered.')
 
+
 getAdapterRegistry()
 
