@@ -18,7 +18,6 @@
 # further licensing information.
 ##
 
-
 #
 # Package definition for com.raytheon.uf.common.datastorage.records
 #
@@ -27,24 +26,28 @@
 #
 #    Date            Ticket#       Engineer       Description
 #    ------------    ----------    -----------    --------------------------
-#    08/31/10                      njensen       Initial Creation.
+#    08/31/10                      njensen        Initial Creation.
+#    Apr 24, 2015    4425          nabowle        Add DoubleDataRecord
 #
 #
 #
 
 
 __all__ = [
-           'ByteDataRecord',
-           'FloatDataRecord',
-           'IntegerDataRecord',
-           'LongDataRecord',
-           'ShortDataRecord',
-           'StringDataRecord',
-           ]
+            'ByteDataRecord',
+            'DoubleDataRecord',
+            'FloatDataRecord',
+            'IntegerDataRecord',
+            'LongDataRecord',
+            'ShortDataRecord',
+            'StringDataRecord'
+          ]
 
 from ByteDataRecord import ByteDataRecord
+from DoubleDataRecord import DoubleDataRecord
 from FloatDataRecord import FloatDataRecord
 from IntegerDataRecord import IntegerDataRecord
 from LongDataRecord import LongDataRecord
 from ShortDataRecord import ShortDataRecord
 from StringDataRecord import StringDataRecord
+
